import os.path
import sys


def common(**kwargs):
    app = kwargs['app']
    base = kwargs['base']
    cloudfront = kwargs['cloudfront']

    # have to pull in anything that we'll be changing
    STATIC_ROOT = kwargs['STATIC_ROOT']
    INSTALLED_APPS = kwargs['INSTALLED_APPS']

    MEDIA_ROOT = '/var/www/' + app + '/uploads/'

    # put any static media here to override app served static media
    STATICMEDIA_MOUNTS = [
        ('/sitemedia', '/var/www/' + app + '/' + app + '/sitemedia'),
    ]

    DATABASES = {
        'default': {
            'ENGINE': 'django.db.backends.postgresql_psycopg2',
            'NAME': app,
            'HOST': '',
            'PORT': 6432,
            'USER': '',
            'PASSWORD': '',
            'ATOMIC_REQUESTS': True,
        }
    }

    COMPRESS_ROOT = os.path.join(base, "../media")
    DEBUG = False

    AWS_S3_CUSTOM_DOMAIN = cloudfront
    AWS_STORAGE_BUCKET_NAME = "thraxil-" + app + "-static-prod"
    AWS_PRELOAD_METADATA = True
    DEFAULT_FILE_STORAGE = 'storages.backends.s3boto3.S3Boto3Storage'
    STATICFILES_STORAGE = 'storages.backends.s3boto3.S3Boto3Storage'
    S3_URL = 'https://%s/' % AWS_S3_CUSTOM_DOMAIN
    STATIC_URL = 'https://%s/media/' % AWS_S3_CUSTOM_DOMAIN
    COMPRESS_ENABLED = True
    COMPRESS_OFFLINE = True
    COMPRESS_ROOT = STATIC_ROOT
    COMPRESS_URL = STATIC_URL
    DEFAULT_FILE_STORAGE = 'storages.backends.s3boto3.S3Boto3Storage'
    MEDIA_URL = S3_URL + '/media/'
    COMPRESS_STORAGE = 'storages.backends.s3boto3.S3Boto3Storage'
    AWS_QUERYSTRING_AUTH = False
    return locals()



import os.path
import sys


def common(**kwargs):
    app = kwargs['app']
    base = kwargs['base']

    DEBUG = True

    ADMINS = ()

    MANAGERS = ADMINS

    DATABASES = {
        'default': {
            'ENGINE': 'django.db.backends.postgresql_psycopg2',
            'NAME': app,
            'HOST': '',
            'PORT': 5432,
            'USER': '',
            'PASSWORD': '',
            'ATOMIC_REQUESTS': True,
        }
    }

    if 'test' in sys.argv:
        DATABASES = {
            'default': {
                'ENGINE': 'django.db.backends.sqlite3',
                'NAME': ':memory:',
                'HOST': '',
                'PORT': '',
                'USER': '',
                'PASSWORD': '',
                'ATOMIC_REQUESTS': True,
            }
        }

    TEST_RUNNER = 'django.test.runner.DiscoverRunner'

    ALLOWED_HOSTS = ['localhost']

    USE_TZ = True
    TIME_ZONE = 'America/New_York'
    LANGUAGE_CODE = 'en-us'
    SITE_ID = 1
    USE_I18N = False
    MEDIA_ROOT = "/var/www/" + app + "/uploads/"
    MEDIA_URL = '/uploads/'
    SECRET_KEY = 'you must override this'
    TEMPLATES = [
        {
            'BACKEND': 'django.template.backends.django.DjangoTemplates',
            'DIRS':  [
                "/var/www/" + app + "/templates/",
                os.path.join(base, "templates"),
            ],
            'APP_DIRS': True,
            'OPTIONS': {
                'context_processors': [
                    'django.contrib.auth.context_processors.auth',
                    'django.template.context_processors.debug',
                    'django.template.context_processors.request',
                    'django.template.context_processors.media',
                    'django.template.context_processors.static',
                    'django.template.context_processors.tz',
                    'django.contrib.messages.context_processors.messages',
                ],
            },
        },
    ]

    MIDDLEWARE = [
        'django.middleware.common.CommonMiddleware',
        'django.contrib.sessions.middleware.SessionMiddleware',
        'django.contrib.auth.middleware.AuthenticationMiddleware',
        'django.contrib.flatpages.middleware.FlatpageFallbackMiddleware',
        'debug_toolbar.middleware.DebugToolbarMiddleware',
        'waffle.middleware.WaffleMiddleware',
        'django.contrib.messages.middleware.MessageMiddleware',
    ]

    ROOT_URLCONF = app + '.urls'

    INSTALLED_APPS = [
        'django.contrib.auth',
        'django.contrib.contenttypes',
        'django.contrib.sessions',
        'django.contrib.sites',
        'django.contrib.flatpages',
        'django.contrib.messages',
        'django.contrib.staticfiles',
        'django.contrib.admin',
        'compressor',
        'debug_toolbar',
        'waffle',
        'smoketest',
        'gunicorn',
    ]

    STATIC_URL = "/media/"
    STATICFILES_DIRS = [
        os.path.abspath(os.path.join(base, "../media/")),
    ]
    STATIC_ROOT = ""
    STATICFILES_FINDERS = [
        'django.contrib.staticfiles.finders.FileSystemFinder',
        'django.contrib.staticfiles.finders.AppDirectoriesFinder',
        'compressor.finders.CompressorFinder',
    ]

    INTERNAL_IPS = ['127.0.0.1']
    DEBUG_TOOLBAR_PANELS = [
        'debug_toolbar.panels.versions.VersionsPanel',
        'debug_toolbar.panels.timer.TimerPanel',
        'debug_toolbar.panels.settings.SettingsPanel',
        'debug_toolbar.panels.headers.HeadersPanel',
        'debug_toolbar.panels.request.RequestPanel',
        'debug_toolbar.panels.sql.SQLPanel',
        'debug_toolbar.panels.staticfiles.StaticFilesPanel',
        'debug_toolbar.panels.templates.TemplatesPanel',
        'debug_toolbar.panels.cache.CachePanel',
        'debug_toolbar.panels.signals.SignalsPanel',
        'debug_toolbar.panels.logging.LoggingPanel',
        'debug_toolbar.panels.redirects.RedirectsPanel',
        'debug_toolbar.panels.profiling.ProfilingPanel',
    ]

    THUMBNAIL_SUBDIR = "thumbs"
    EMAIL_SUBJECT_PREFIX = "[" + app + "] "
    EMAIL_HOST = 'localhost'
    SERVER_EMAIL = app + "@thraxil.org"
    DEFAULT_FROM_EMAIL = SERVER_EMAIL

    # put any static media here to override app served static media
    STATICMEDIA_MOUNTS = [
        ('/sitemedia', 'sitemedia'),
    ]

    COMPRESS_URL = "/media/"
    COMPRESS_ROOT = "media/"

    COMPRESS_CSS_FILTERS = [
        'compressor.filters.css_default.CssAbsoluteFilter',
        'compressor.filters.cssmin.CSSMinFilter',
    ]

    SESSION_ENGINE = "django.contrib.sessions.backends.signed_cookies"
    SESSION_COOKIE_HTTPONLY = True
    SESSION_COOKIE_AGE = 60 * 60 * 24 * 265 * 5

    LOGGING = {
        'version': 1,
        'disable_existing_loggers': True,
    }

    return locals()



# flake8: noqa
# docker-compose settings doesn't really have to do much
# since it's a dev environment and is mostly covered by
# settings_shared. mostly, it just has to set up some
# defaults
import os
import sys


def common(**kwargs):
    DEBUG = True
    DATABASES = {
        'default': {
            'ENGINE': 'django.db.backends.postgresql_psycopg2',
            'NAME': 'postgres',
            'USER': 'postgres',
            'HOST': 'db',
            'PORT': 5432,
            'ATOMIC_REQUESTS': True,
        }
    }
    EMAIL_BACKEND = 'django.core.mail.backends.dummy.EmailBackend'
    BROKER_URL = "amqp://guest:guest@rabbitmq:5672/"
    CELERY_BROKER_URL = BROKER_URL
    return locals()



import os
import sys


def common(**kwargs):
    app = kwargs['app']
    base = kwargs['base']
    celery = kwargs.get('celery', False)

    # have to pull in anything that we'll be changing
    STATIC_ROOT = kwargs['STATIC_ROOT']
    INSTALLED_APPS = kwargs['INSTALLED_APPS']
    MIDDLEWARE= kwargs['MIDDLEWARE']

    # required settings:
    SECRET_KEY = os.environ['SECRET_KEY']
    CELERY_BROKER_URL = None
    if celery:
        CELERY_BROKER_URL = os.environ['BROKER_URL']

    # optional/defaulted settings
    DB_NAME = os.environ.get('DB_NAME', app)
    DB_HOST = os.environ.get(
        'DB_HOST',
        os.environ.get('POSTGRESQL_PORT_5432_TCP_ADDR', ''))
    DB_PORT = int(
        os.environ.get(
            'DB_PORT',
            os.environ.get('POSTGRESQL_PORT_54342_TCP_PORT', 5432)))
    DB_USER = os.environ.get('DB_USER', '')
    DB_PASSWORD = os.environ.get('DB_PASSWORD', '')

    AWS_S3_CUSTOM_DOMAIN = os.environ.get('AWS_S3_CUSTOM_DOMAIN', '')
    AWS_STORAGE_BUCKET_NAME = os.environ.get('AWS_STORAGE_BUCKET_NAME', '')
    AWS_ACCESS_KEY = os.environ.get('AWS_ACCESS_KEY', '')
    AWS_SECRET_KEY = os.environ.get('AWS_SECRET_KEY', '')
    AWS_ACCESS_KEY_ID = AWS_ACCESS_KEY
    AWS_SECRET_ACCESS_KEY = AWS_SECRET_KEY
    AWS_DEFAULT_ACL = 'public-read'

    if 'ALLOWED_HOSTS' in os.environ:
        ALLOWED_HOSTS = os.environ['ALLOWED_HOSTS'].split(',')

    TIME_ZONE = os.environ.get('TIME_ZONE', 'America/New_York')

    EMAIL_HOST = os.environ.get(
        'EMAIL_HOST',
        os.environ.get('POSTFIX_PORT_25_TCP_ADDR', 'localhost'))
    EMAIL_PORT = os.environ.get(
        'EMAIL_PORT',
        os.environ.get('POSTFIX_PORT_25_TCP_PORT', 25))

    SERVER_EMAIL = os.environ.get('SERVER_EMAIL', app + "@thraxil.org")

    # -------------------------------------------

    DEBUG = False

    DATABASES = {
        'default': {
            'ENGINE': 'django.db.backends.postgresql_psycopg2',
            'NAME': DB_NAME,
            'HOST': DB_HOST,
            'PORT': DB_PORT,
            'USER': DB_USER,
            'PASSWORD': DB_PASSWORD,
            }
    }

    if AWS_S3_CUSTOM_DOMAIN:
        AWS_PRELOAD_METADATA = True
        DEFAULT_FILE_STORAGE = 'storages.backends.s3boto3.S3Boto3Storage'
        S3_URL = 'https://%s/' % AWS_S3_CUSTOM_DOMAIN
        # static data, e.g. css, js, etc.
        STATICFILES_STORAGE = 'storages.backends.s3boto3.S3Boto3Storage'
        STATIC_URL = 'https://%s/media/' % AWS_S3_CUSTOM_DOMAIN
        COMPRESS_ENABLED = True
        COMPRESS_OFFLINE = True
        COMPRESS_ROOT = STATIC_ROOT
        COMPRESS_URL = STATIC_URL
        COMPRESS_STORAGE = 'storages.backends.s3boto3.S3Boto3Storage'

    LOGGING = {
        'version': 1,
        'disable_existing_loggers': False,
    }

    RAVEN_DSN = os.environ.get('RAVEN_DSN', None)

    if RAVEN_DSN:
        INSTALLED_APPS += [
            'raven.contrib.django.raven_compat',
        ]
        RAVEN_CONFIG = {
            'dsn': RAVEN_DSN,
        }

    return locals()



from setuptools import setup, find_packages

setup(
    name="thraxilsettings",
    version="5.0.0",
    author="Anders Pearson",
    author_email="anders@columbia.edu",
    url="https://github.com/thraxil/thraxilsettings",
    description="My common base settings",
    long_description="common settings i use across all my apps",
    install_requires = [
        "django_compressor",
        "django-debug-toolbar",
        "django-waffle",
        "django-smoketest",
        "django-storages",
        "boto3",
        "raven",
        "gunicorn",
    ],
    scripts = [],
    license = "BSD",
    platforms = ["any"],
    zip_safe=False,
    package_data = {'' : ['*.*']},
    packages=['thraxilsettings'],
    )
